@@ -11,6 +11,7 @@
 """Library of functions for deploying artifacts to Nexus."""
 
 import concurrent.futures
+import datetime
 import errno
 import glob
 import gzip
@@ -194,7 +195,7 @@ def _get_node_from_xml(xml_data, tag_name):
     try:
         dom1 = parseString(xml_data)
         childnode = dom1.getElementsByTagName(tag_name)[0]
-    except:
+    except Exception:
         _log_error_and_exit("Received bad XML, can not find tag {}".format(tag_name), xml_data)
     return childnode.firstChild.data
 
@@ -268,7 +269,6 @@ def copy_archives(workspace, pattern=None):
     log.debug("Files found: {}".format(paths))
 
     no_dups_paths = _remove_duplicates_and_sort(paths)
-
     for src in no_dups_paths:
         if len(os.path.basename(src)) > 255:
             log.warn("Filename {} is over 255 characters. Skipping...".format(os.path.basename(src)))
@@ -286,6 +286,16 @@ def copy_archives(workspace, pattern=None):
         else:
             log.info("Not copying directories: {}.".format(src))
 
+    # Create a temp file to handle empty dirs in AWS S3 buckets.
+    if os.environ.get("S3_BUCKET") is not None:
+        now = datetime.datetime.now()
+        p = now.strftime("_%d%m%Y_%H%M%S_")
+        for dirpath, dirnames, files in os.walk(dest_dir):
+            if not files:
+                fd, tmp = tempfile.mkstemp(prefix=p, dir=dirpath)
+                os.close(fd)
+                log.debug("temp file created in dir: {}.".format(dirpath))
+
 
 def deploy_archives(nexus_url, nexus_path, workspace, pattern=None):
     """Archive files to a Nexus site repository named logs.
